<?php
/**
 * This class contains functions for producing natural,
 * grammatically correct text.
 *
 * It was written with English in mind - if you are using any other language
 * it might not work.
 */
class HGrammar
{
	/**
	 * Returns a the singular/plural version of a word based on a number
	 * passed with it.
	 *
	 * This function is inspired by the CCodeModel::pluralize() function in
	 * Yii's core.
	 *
	 * @param int $number
	 * @param string $singular String to return
	 * @param string $plural Plural for irregular nouns (will guess if nothing provided)
	 */
	public function plural ($number,$singular,$plural = null)
	{
		if ($number == 1)
		{
			return $singular;
		} else
		{
			if (is_null($plural))
			{
				$rules=array(
					'/(x|ch|ss|sh|us|as|is|os)$/i' => '\1es',
					'/(?:([^f])fe|([lr])f)$/i' => '\1\2ves',
					'/(m)an$/i' => '\1en',
					'/(child)$/i' => '\1ren',
					'/(r|t)y$/i' => '\1ies',
					'/s$/' => 's',
				);
				foreach($rules as $rule=>$replacement)
				{
					if(preg_match($rule,$singular))
						return preg_replace($rule,$replacement,$singular);
				}
				return $singular.'s';
			}
			else
				return $plural;
		}
	}

	/**
	 * Switches between two words based on the first letter of a
	 * given word being a vowel/consonant.  Used for a pig / an animal
	 * @param string $word The word to be checked
	 * @param string $vowel Value to return if $word begins with a vowel
	 * @param string $consonant Value to return if $word begins with a consonant
	 */
	public function vowelStart($word,$consonant,$vowel)
	{
		if (preg_match('/^[aeiou8]/i',ltrim($word)))
			return $vowel;
		else
			return $consonant;
	}

	/**
	 * Creates a list like apples, tomatoes and grapes from
	 * an array of (apples,tomatoes,grapes)
	 * 
	 * @param array $array
	 * @param string $finalSeperator Defaults to ' and '
	 * @param string $seperator Defaults to ', '
	 */
	public static function commaList ($array = array(),$finalSeparator=' and ',$separator=', ')
	{
		if (empty($array))
			return '';

		// get last element
		$last = array_pop ($array);

		// if it was the only element - return it
		if (!count ($array))
			return $last;

		return implode ($separator, $array).$finalSeparator.$last;
	}
}

?>
